@@ -41,6 +41,10 @@ void IdentifierTest::testStringToIdentifier_data()
     QTest::newRow("special chars2") << " */$" << "_";
     QTest::newRow("Upper case") << "a A b2" << "a_A_b2";
     QTest::newRow("non-alpha") << "1" << "_1";
+    QTest::newRow("non-latin1") << QString::fromUtf8("Ñ©Æ ᑫኂ") << "NcAE_kexi";
+    QTest::newRow("umlauts")
+            << QString::fromUtf8("Falsches Üben von Xylophonmusik quält jeden größeren Zwerg")
+            << "Falsches_Ueben_von_Xylophonmusik_quaelt_jeden_groesseren_Zwerg";
 }
 
 void IdentifierTest::testStringToIdentifier()
@@ -76,23 +80,27 @@ void IdentifierTest::testIsIdentifier()
 void IdentifierTest::escapeIdentifier_data()
 {
     QTest::addColumn<QString>("string");
-    QTest::addColumn<QString>("result");
-    QTest::newRow("empty") << "" << QString();
-    QTest::newRow("empty") << QString() << QString();
-    QTest::newRow("\"") << "\"" << "\"\"";
-    QTest::newRow("\"-\"") << "\"-\"" << "\"\"-\"\"";
-    QTest::newRow("\t") << "\t" << "\t";
-    QTest::newRow("alpha") << "a b" << "a b";
+    QTest::addColumn<QString>("result"); // quotes not always added
+    QTest::addColumn<QString>("resultWithForcedQuotes"); // quotes always added
+    QTest::newRow("empty") << "" << QString() << "\"\"";
+    QTest::newRow("empty") << QString() << QString() << "\"\"";
+    QTest::newRow("\"") << "\"" << "\"\"\"\"" << "\"\"\"\"";
+    QTest::newRow("\"-\"") << "\"-\"" << "\"\"\"-\"\"\"" << "\"\"\"-\"\"\"";
+    QTest::newRow("\t") << "\t" << "\"\t\"" << "\"\t\"";
+    QTest::newRow("id") << "id" << "id" << "\"id\"";
+    QTest::newRow("keyword") << "select" << "\"select\"" << "\"select\"";
+    QTest::newRow("alpha") << "a b" << "\"a b\"" << "\"a b\"";
 }
 
 void IdentifierTest::escapeIdentifier()
 {
     QFETCH(QString, string);
     QFETCH(QString, result);
+    QFETCH(QString, resultWithForcedQuotes);
     QCOMPARE(KDb::escapeIdentifier(string), result);
     QCOMPARE(KDb::escapeIdentifier(string.toLatin1()), result.toLatin1());
-    QCOMPARE(KDb::escapeIdentifierAndAddQuotes(string), QString::fromLatin1("\"%1\"").arg(result));
-    QCOMPARE(KDb::escapeIdentifierAndAddQuotes(string.toLatin1()), '"' + result.toLatin1() + '"');
+    QCOMPARE(KDb::escapeIdentifierAndAddQuotes(string), resultWithForcedQuotes);
+    QCOMPARE(KDb::escapeIdentifierAndAddQuotes(string.toLatin1()), resultWithForcedQuotes.toLatin1());
 }
 
 void IdentifierTest::cleanupTestCase()
