@@ -30,6 +30,7 @@
 #include <KPluginFactory>
 
 #include <QApplication>
+#include <QMimeDatabase>
 #include <QTime>
 #include <QWidget>
 
@@ -102,6 +103,7 @@ void DriverManagerInternal::lookupDriversInternal()
             = KDbJsonTrader::self()->query(QLatin1String("KDb/Driver"));
     const QString expectedVersion = QString::fromLatin1("%1.%2")
             .arg(KDB_STABLE_VERSION_MAJOR).arg(KDB_STABLE_VERSION_MINOR);
+    QMimeDatabase mimedb;
     foreach(const QPluginLoader *loader, offers) {
         //QJsonObject json = loader->metaData();
         //drivermanagerDebug() << json;
@@ -123,7 +125,18 @@ void DriverManagerInternal::lookupDriversInternal()
             }
             continue;
         }
-        foreach (const QString& mimeType, metaData->mimeTypes()) {
+        QSet<QString> resolvedMimeTypes;
+        for (const QString &mimeType : metaData->mimeTypes()) {
+            const QMimeType mime = mimedb.mimeTypeForName(mimeType);
+            if (!mime.isValid()) {
+                kdbWarning() << "Driver with ID" << metaData->id()
+                             << "specifies the unknown MIME type"
+                             << mimeType;
+                continue;
+            }
+           resolvedMimeTypes.insert(mime.name());
+        }
+        for (const QString &mimeType : resolvedMimeTypes) {
             m_metadata_by_mimetype.insertMulti(mimeType, metaData.data());
         }
         m_driversMetaData.insert(metaData->id(), metaData.data());
@@ -147,7 +160,7 @@ QStringList DriverManagerInternal::driverIds()
 const KDbDriverMetaData* DriverManagerInternal::driverMetaData(const QString &id)
 {
     if (!lookupDrivers()) {
-        return 0;
+        return nullptr;
     }
     const KDbDriverMetaData *metaData = m_driversMetaData.value(id.toLower());
     if (!metaData || m_result.isError()) {
@@ -162,7 +175,12 @@ QStringList DriverManagerInternal::driverIdsForMimeType(const QString &mimeType)
     if (!lookupDrivers()) {
         return QStringList();
     }
-    const QList<KDbDriverMetaData*> metaDatas(m_metadata_by_mimetype.values(mimeType.toLower()));
+    QMimeDatabase mimedb;
+    const QMimeType mime = mimedb.mimeTypeForName(mimeType.toLower());
+    if (!mime.isValid()) {
+        return QStringList();
+    }
+    const QList<KDbDriverMetaData*> metaDatas(m_metadata_by_mimetype.values(mime.name()));
     QStringList result;
     foreach (const KDbDriverMetaData* metaData, metaDatas) {
         result.append(metaData->id());
@@ -178,12 +196,12 @@ QStringList DriverManagerInternal::possibleProblems() const
 KDbDriver* DriverManagerInternal::driver(const QString& id)
 {
     if (!lookupDrivers())
-        return 0;
+        return nullptr;
 
     clearResult();
     drivermanagerDebug() << "loading" << id;
 
-    KDbDriver *driver = 0;
+    KDbDriver *driver = nullptr;
     if (!id.isEmpty()) {
         driver = m_drivers.value(id.toLower());
     }
@@ -193,7 +211,7 @@ KDbDriver* DriverManagerInternal::driver(const QString& id)
     if (!m_driversMetaData.contains(id.toLower())) {
         m_result = KDbResult(ERR_DRIVERMANAGER,
                              tr("Could not find database driver \"%1\".").arg(id));
-        return 0;
+        return nullptr;
     }
 
     const KDbDriverMetaData *metaData = m_driversMetaData.value(id.toLower());
@@ -206,7 +224,7 @@ KDbDriver* DriverManagerInternal::driver(const QString& id)
         (void)loader.load();
         m_result.setServerMessage(loader.errorString());
         kdbWarning() << m_result.message() << m_result.serverMessage();
-        return 0;
+        return nullptr;
     }
     driver = factory->create<KDbDriver>();
     if (!driver) {
@@ -215,7 +233,7 @@ KDbDriver* DriverManagerInternal::driver(const QString& id)
                                 .arg(metaData->id(),
                                      metaData->fileName()));
         kdbWarning() << m_result.message();
-        return 0;
+        return nullptr;
     }
     driver->setMetaData(metaData);
     m_drivers.insert(id.toLower(), driver);
