@@ -1,5 +1,5 @@
 /* This file is part of the KDE project
-   Copyright (C) 2006-2015 Jarosław Staniek <staniek@kde.org>
+   Copyright (C) 2006-2016 Jarosław Staniek <staniek@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -29,19 +29,32 @@
 #include <vector>
 
 //! @internal
-class KDbLookupFieldSchema::RecordSource::Private
+class Q_DECL_HIDDEN KDbLookupFieldSchemaRecordSource::Private
 {
 public:
     Private()
-            : type(KDbLookupFieldSchema::RecordSource::NoType) {
+            : type(KDbLookupFieldSchemaRecordSource::Type::None) {
     }
-    KDbLookupFieldSchema::RecordSource::Type type;
+    Private(const Private &other) {
+        copy(other);
+    }
+#define KDbLookupFieldSchemaRecordSourcePrivateArgs(o) std::tie(o.type, o.name, o.values)
+    void copy(const Private &other) {
+        KDbLookupFieldSchemaRecordSourcePrivateArgs((*this))
+                = KDbLookupFieldSchemaRecordSourcePrivateArgs(other);
+    }
+    bool operator==(const KDbLookupFieldSchemaRecordSource::Private &other) const {
+        return KDbLookupFieldSchemaRecordSourcePrivateArgs((*this))
+                == KDbLookupFieldSchemaRecordSourcePrivateArgs(other);
+    }
+
+    KDbLookupFieldSchemaRecordSource::Type type;
     QString name;
     QStringList values;
 };
 
 //! @internal
-class KDbLookupFieldSchema::Private
+class Q_DECL_HIDDEN KDbLookupFieldSchema::Private
 {
 public:
     Private()
@@ -51,8 +64,20 @@ public:
             , columnHeadersVisible(KDB_LOOKUP_FIELD_DEFAULT_HEADERS_VISIBLE)
             , limitToList(KDB_LOOKUP_FIELD_DEFAULT_LIMIT_TO_LIST) {
     }
+    Private(const Private &other) {
+        copy(other);
+    }
+#define KDbLookupFieldSchemaPrivateArgs(o) std::tie(o.recordSource, o.boundColumn, o.visibleColumns, \
+                    o.columnWidths, o.maxVisibleRecords, o.displayWidget, \
+                    o.columnHeadersVisible, o.limitToList)
+    void copy(const Private &other) {
+        KDbLookupFieldSchemaPrivateArgs((*this)) = KDbLookupFieldSchemaPrivateArgs(other);
+    }
+    bool operator==(const KDbLookupFieldSchema::Private &other) const {
+        return KDbLookupFieldSchemaPrivateArgs((*this)) == KDbLookupFieldSchemaPrivateArgs(other);
+    }
 
-    RecordSource recordSource;
+    KDbLookupFieldSchemaRecordSource recordSource;
     int boundColumn;
     QList<int> visibleColumns;
     QList<int> columnWidths;
@@ -75,14 +100,14 @@ public:
             QLatin1String("valuelist"),
             QLatin1String("fieldlist")})
     {
-        typesForNames.insert(QLatin1String("table"), KDbLookupFieldSchema::RecordSource::Table);
-        typesForNames.insert(QLatin1String("query"), KDbLookupFieldSchema::RecordSource::Query);
-        typesForNames.insert(QLatin1String("sql"), KDbLookupFieldSchema::RecordSource::SQLStatement);
-        typesForNames.insert(QLatin1String("valuelist"), KDbLookupFieldSchema::RecordSource::ValueList);
-        typesForNames.insert(QLatin1String("fieldlist"), KDbLookupFieldSchema::RecordSource::KDbFieldList);
+        typesForNames.insert(QLatin1String("table"), KDbLookupFieldSchemaRecordSource::Type::Table);
+        typesForNames.insert(QLatin1String("query"), KDbLookupFieldSchemaRecordSource::Type::Query);
+        typesForNames.insert(QLatin1String("sql"), KDbLookupFieldSchemaRecordSource::Type::SQLStatement);
+        typesForNames.insert(QLatin1String("valuelist"), KDbLookupFieldSchemaRecordSource::Type::ValueList);
+        typesForNames.insert(QLatin1String("fieldlist"), KDbLookupFieldSchemaRecordSource::Type::KDbFieldList);
     }
     const std::vector<QString> typeNames;
-    QHash<QString, KDbLookupFieldSchema::RecordSource::Type> typesForNames;
+    QHash<QString, KDbLookupFieldSchemaRecordSource::Type> typesForNames;
 private:
     Q_DISABLE_COPY(LookupFieldSchemaStatic)
 };
@@ -91,66 +116,65 @@ Q_GLOBAL_STATIC(LookupFieldSchemaStatic, KDb_lookupFieldSchemaStatic)
 
 //----------------------------
 
-KDbLookupFieldSchema::RecordSource::RecordSource()
+KDbLookupFieldSchemaRecordSource::KDbLookupFieldSchemaRecordSource()
         : d(new Private)
 {
 }
 
-KDbLookupFieldSchema::RecordSource::RecordSource(const RecordSource& other)
-        : d(new Private)
+KDbLookupFieldSchemaRecordSource::KDbLookupFieldSchemaRecordSource(const KDbLookupFieldSchemaRecordSource& other)
+        : d(new Private(*other.d))
 {
-    *d = *other.d;
 }
 
-KDbLookupFieldSchema::RecordSource::~RecordSource()
+KDbLookupFieldSchemaRecordSource::~KDbLookupFieldSchemaRecordSource()
 {
     delete d;
 }
 
-KDbLookupFieldSchema::RecordSource::Type KDbLookupFieldSchema::RecordSource::type() const
+KDbLookupFieldSchemaRecordSource::Type KDbLookupFieldSchemaRecordSource::type() const
 {
     return d->type;
 }
 
-void KDbLookupFieldSchema::RecordSource::setType(Type type)
+void KDbLookupFieldSchemaRecordSource::setType(Type type)
 {
     d->type = type;
 }
 
-QString KDbLookupFieldSchema::RecordSource::name() const
+QString KDbLookupFieldSchemaRecordSource::name() const
 {
     return d->name;
 }
 
-void KDbLookupFieldSchema::RecordSource::setName(const QString& name)
+void KDbLookupFieldSchemaRecordSource::setName(const QString& name)
 {
     d->name = name;
     d->values.clear();
 }
 
-QString KDbLookupFieldSchema::RecordSource::typeName() const
+QString KDbLookupFieldSchemaRecordSource::typeName() const
 {
     Q_ASSERT(size_t(d->type) < KDb_lookupFieldSchemaStatic->typeNames.size());
-    return KDb_lookupFieldSchemaStatic->typeNames[d->type];
+    return KDb_lookupFieldSchemaStatic->typeNames[static_cast<int>(d->type)];
 }
 
-void KDbLookupFieldSchema::RecordSource::setTypeByName(const QString& typeName)
+void KDbLookupFieldSchemaRecordSource::setTypeByName(const QString& typeName)
 {
-    setType(KDb_lookupFieldSchemaStatic->typesForNames.value(typeName, NoType));
+    setType(KDb_lookupFieldSchemaStatic->typesForNames.value(typeName, Type::None));
 }
 
-QStringList KDbLookupFieldSchema::RecordSource::values() const
+QStringList KDbLookupFieldSchemaRecordSource::values() const
 {
     return d->values;
 }
 
-void KDbLookupFieldSchema::RecordSource::setValues(const QStringList& values)
+void KDbLookupFieldSchemaRecordSource::setValues(const QStringList& values)
 {
     d->name.clear();
     d->values = values;
 }
 
-KDbLookupFieldSchema::RecordSource& KDbLookupFieldSchema::RecordSource::operator=(const RecordSource & other)
+KDbLookupFieldSchemaRecordSource& KDbLookupFieldSchemaRecordSource::operator=(const KDbLookupFieldSchemaRecordSource & other)
 {
     if (this != &other) {
         *d = *other.d;
@@ -158,9 +182,14 @@ KDbLookupFieldSchema::RecordSource& KDbLookupFieldSchema::RecordSource::operator
     return *this;
 }
 
-QDebug operator<<(QDebug dbg, const KDbLookupFieldSchema::RecordSource& source)
+bool KDbLookupFieldSchemaRecordSource::operator==(const KDbLookupFieldSchemaRecordSource &other) const
 {
-    dbg.nospace() << "RecordSource TYPE:";
+    return *d == *other.d;
+}
+
+QDebug operator<<(QDebug dbg, const KDbLookupFieldSchemaRecordSource& source)
+{
+    dbg.nospace() << "LookupFieldSchemaRecordSource TYPE:";
     dbg.space() << source.typeName();
     dbg.space() << "NAME:";
     dbg.space() << source.name();
@@ -177,9 +206,8 @@ KDbLookupFieldSchema::KDbLookupFieldSchema()
 }
 
 KDbLookupFieldSchema::KDbLookupFieldSchema(const KDbLookupFieldSchema &schema)
-: d(new Private)
+: d(new Private(*schema.d))
 {
-    *d = *schema.d;
 }
 
 KDbLookupFieldSchema::~KDbLookupFieldSchema()
@@ -243,19 +271,20 @@ static bool setColumnWidths(KDbLookupFieldSchema *lookup, const QVariant &val)
 static bool setDisplayWidget(KDbLookupFieldSchema *lookup, const QVariant &val)
 {
     bool ok;
-    const int ival = val.toInt(&ok);
-    if (!ok || ival > KDbLookupFieldSchema::ListBox)
+    const uint ival = val.toUInt(&ok);
+    if (!ok || ival > static_cast<uint>(KDbLookupFieldSchema::DisplayWidget::ListBox)) {
         return false;
+    }
     lookup->setDisplayWidget(static_cast<KDbLookupFieldSchema::DisplayWidget>(ival));
     return true;
 }
 
-KDbLookupFieldSchema::RecordSource KDbLookupFieldSchema::recordSource() const
+KDbLookupFieldSchemaRecordSource KDbLookupFieldSchema::recordSource() const
 {
     return d->recordSource;
 }
 
-void KDbLookupFieldSchema::setRecordSource(const KDbLookupFieldSchema::RecordSource& recordSource)
+void KDbLookupFieldSchema::setRecordSource(const KDbLookupFieldSchemaRecordSource& recordSource)
 {
     d->recordSource = recordSource;
 }
@@ -291,7 +320,9 @@ QDebug operator<<(QDebug dbg, const KDbLookupFieldSchema& lookup)
     dbg.space() << "maxVisibleRecords:";
     dbg.space() << lookup.maxVisibleRecords();
     dbg.space() << "displayWidget:";
-    dbg.space() << (lookup.displayWidget() == KDbLookupFieldSchema::ComboBox ? "ComboBox" : "ListBox");
+    dbg.space() << (lookup.displayWidget() == KDbLookupFieldSchema::DisplayWidget::ComboBox
+                        ? "ComboBox"
+                        : "ListBox");
     dbg.space() << "columnHeadersVisible:";
     dbg.space() << lookup.columnHeadersVisible();
     dbg.space() << "limitToList:";
@@ -315,7 +346,7 @@ QDebug operator<<(QDebug dbg, const KDbLookupFieldSchema& lookup)
 KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& lookupEl)
 {
     KDbLookupFieldSchema *lookupFieldSchema = new KDbLookupFieldSchema();
-    KDbLookupFieldSchema::RecordSource recordSource;
+    KDbLookupFieldSchemaRecordSource recordSource;
     for (QDomNode node = lookupEl.firstChild(); !node.isNull(); node = node.nextSibling()) {
         QDomElement el = node.toElement();
         const QByteArray name(el.tagName().toLatin1());
@@ -327,7 +358,7 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
                                                                  #"fieldlist" (basically a list of
                                                                  #column names of a table/query,
                                                                  #"Field List" as in MSA)
-              <name>string</name> #table/query name, etc. or KEXISQL SELECT QUERY
+              <name>string</name> #table/query name, etc. or KDbSQL SELECT QUERY
               <values><value>...</value> #for "valuelist" type
                 <value>...</value>
               </values>
@@ -339,7 +370,7 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
                 }
                 else if (childName == "name") {
                     recordSource.setName(el.text());
-//! @todo handle fieldlist (retrieve from external table or so?), use RecordSource::setValues()
+//! @todo handle fieldlist (retrieve from external table or so?), use KDbLookupFieldSchemaRecordSource::setValues()
                 }
             }
         } else if (name == "bound-column") {
@@ -434,10 +465,10 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
         else if (name == "display-widget") {
             const QByteArray displayWidgetName(el.text().toLatin1());
             if (displayWidgetName == "combobox") {
-                lookupFieldSchema->setDisplayWidget(KDbLookupFieldSchema::ComboBox);
+                lookupFieldSchema->setDisplayWidget(KDbLookupFieldSchema::DisplayWidget::ComboBox);
             }
             else if (displayWidgetName == "listbox") {
-                lookupFieldSchema->setDisplayWidget(KDbLookupFieldSchema::ListBox);
+                lookupFieldSchema->setDisplayWidget(KDbLookupFieldSchema::DisplayWidget::ListBox);
             }
         }
     }
@@ -447,8 +478,9 @@ KDbLookupFieldSchema *KDbLookupFieldSchema::loadFromDom(const QDomElement& looku
 
 void KDbLookupFieldSchema::saveToDom(QDomDocument *doc, QDomElement *parentEl)
 {
-    Q_ASSERT(doc);
-    Q_ASSERT(parentEl);
+    if (!doc || !parentEl) {
+        return;
+    }
     QDomElement lookupColumnEl, recordSourceEl, recordSourceTypeEl, nameEl;
     if (!recordSource().name().isEmpty()) {
         lookupColumnEl = doc->createElement(QLatin1String("lookup-column"));
@@ -522,7 +554,7 @@ void KDbLookupFieldSchema::saveToDom(QDomDocument *doc, QDomElement *parentEl)
         lookupColumnEl.appendChild(displayWidgetEl);
         displayWidgetEl.appendChild(
             doc->createTextNode(
-                QLatin1String((displayWidget() == ListBox) ? "listbox" : "combobox")));
+                QLatin1String((displayWidget() == DisplayWidget::ListBox) ? "listbox" : "combobox")));
     }
 }
 
@@ -539,7 +571,7 @@ bool KDbLookupFieldSchema::setProperty(const QByteArray& propertyName, const QVa
         || "rowSourceType" == propertyName
         || "rowSourceValues" == propertyName)
     {
-        KDbLookupFieldSchema::RecordSource recordSource(this->recordSource());
+        KDbLookupFieldSchemaRecordSource recordSource(this->recordSource());
         if ("rowSource" == propertyName)
             recordSource.setName(value.toString());
         else if ("rowSourceType" == propertyName)
@@ -584,7 +616,7 @@ bool KDbLookupFieldSchema::setProperty(const QByteArray& propertyName, const QVa
 bool KDbLookupFieldSchema::setProperties(const QMap<QByteArray, QVariant>& values)
 {
     QMap<QByteArray, QVariant>::ConstIterator it;
-    KDbLookupFieldSchema::RecordSource recordSource(this->recordSource());
+    KDbLookupFieldSchemaRecordSource recordSource(this->recordSource());
     bool ok;
     bool updateRecordSource = false;
     if ((it = values.find("rowSource")) != values.constEnd()) {
@@ -712,3 +744,16 @@ void KDbLookupFieldSchema::setDisplayWidget(DisplayWidget widget)
 {
     d->displayWidget = widget;
 }
+
+KDbLookupFieldSchema& KDbLookupFieldSchema::operator=(const KDbLookupFieldSchema & other)
+{
+    if (this != &other) {
+        *d = *other.d;
+    }
+    return *this;
+}
+
+bool KDbLookupFieldSchema::operator==(const KDbLookupFieldSchema &other) const
+{
+    return *d == *other.d;
+}
