@@ -18,31 +18,23 @@
 */
 
 #include "KDbQuerySchema_p.h"
+#include "KDbConnection.h"
+#include "KDbConnection_p.h"
+#include "KDbOrderByColumn.h"
+#include "kdb_debug.h"
 
-KDbQuerySchema::Private::Private(KDbQuerySchema* q, Private* copy)
+KDbQuerySchemaPrivate::KDbQuerySchemaPrivate(KDbQuerySchema* q, KDbQuerySchemaPrivate* copy)
         : query(q)
         , masterTable(nullptr)
         , fakeRecordIdField(nullptr)
         , fakeRecordIdCol(nullptr)
-        , conn(nullptr)
         , maxIndexWithAlias(-1)
         , visibility(64)
-        , fieldsExpanded(nullptr)
-        , visibleFieldsExpanded(nullptr)
-        , internalFields(nullptr)
-        , fieldsExpandedWithInternalAndRecordId(nullptr)
-        , visibleFieldsExpandedWithInternalAndRecordId(nullptr)
-        , fieldsExpandedWithInternal(nullptr)
-        , visibleFieldsExpandedWithInternal(nullptr)
         , orderByColumnList(nullptr)
         , autoincFields(nullptr)
-        , columnsOrder(nullptr)
-        , columnsOrderWithoutAsterisks(nullptr)
-        , columnsOrderExpanded(nullptr)
         , pkeyFieldsOrder(nullptr)
         , pkeyFieldCount(0)
         , tablesBoundToColumns(64, -1) // will be resized if needed
-        , ownedVisibleColumns(nullptr)
         , regenerateExprAliases(false)
 {
     visibility.fill(false);
@@ -50,27 +42,12 @@ KDbQuerySchema::Private::Private(KDbQuerySchema* q, Private* copy)
         // deep copy
         *this = *copy;
         // <clear, so computeFieldsExpanded() will re-create it>
-        fieldsExpanded = nullptr;
-        visibleFieldsExpanded = nullptr;
-        internalFields = nullptr;
-        columnsOrder = nullptr;
-        columnsOrderWithoutAsterisks = nullptr;
-        columnsOrderExpanded = nullptr;
         orderByColumnList = nullptr;
         autoincFields = nullptr;
-        autoIncrementSQLFieldsList.clear();
-        columnInfosByNameExpanded.clear();
-        columnInfosByName.clear();
-        ownedVisibleColumns = nullptr;
-        fieldsExpandedWithInternalAndRecordId = nullptr;
-        visibleFieldsExpandedWithInternalAndRecordId = nullptr;
-        fieldsExpandedWithInternal = nullptr;
-        visibleFieldsExpandedWithInternal = nullptr;
+        autoIncrementSqlFieldsList.clear();
         pkeyFieldsOrder = nullptr;
         fakeRecordIdCol = nullptr;
         fakeRecordIdField = nullptr;
-        conn = nullptr;
-        ownedVisibleColumns = nullptr;
         // </clear, so computeFieldsExpanded() will re-create it>
         if (!copy->whereExpr.isNull()) {
             whereExpr = copy->whereExpr.clone();
@@ -86,38 +63,19 @@ KDbQuerySchema::Private::Private(KDbQuerySchema* q, Private* copy)
     }
 }
 
-KDbQuerySchema::Private::~Private()
+KDbQuerySchemaPrivate::~KDbQuerySchemaPrivate()
 {
+    if (recentConnection) {
+        recentConnection->d->removeFieldsExpanded(query);
+    }
     delete orderByColumnList;
     delete autoincFields;
-    delete columnsOrder;
-    delete columnsOrderWithoutAsterisks;
-    delete columnsOrderExpanded;
     delete pkeyFieldsOrder;
     delete fakeRecordIdCol;
     delete fakeRecordIdField;
-    delete ownedVisibleColumns;
-    if (fieldsExpanded) {
-        qDeleteAll(*fieldsExpanded);
-        delete fieldsExpanded;
-    }
-    if (internalFields) {
-        qDeleteAll(*internalFields);
-        delete internalFields;
-    }
-    delete fieldsExpandedWithInternalAndRecordId;
-    delete visibleFieldsExpandedWithInternalAndRecordId;
-    delete fieldsExpandedWithInternal;
-    delete visibleFieldsExpandedWithInternal;
 }
 
-//static
-KDbQuerySchema* KDbQuerySchema::Private::createQuery(KDbConnection *conn)
-{
-    return new KDbQuerySchema(conn);
-}
-
-void KDbQuerySchema::Private::clear()
+void KDbQuerySchemaPrivate::clear()
 {
     columnAliases.clear();
     tableAliases.clear();
@@ -134,57 +92,30 @@ void KDbQuerySchema::Private::clear()
     columnPositionsForAliases.clear();
 }
 
-void KDbQuerySchema::Private::clearCachedData()
+void KDbQuerySchemaPrivate::clearCachedData()
 {
     if (orderByColumnList) {
         orderByColumnList->clear();
     }
-    if (fieldsExpanded) {
-        delete columnsOrder;
-        columnsOrder = nullptr;
-        delete columnsOrderWithoutAsterisks;
-        columnsOrderWithoutAsterisks = nullptr;
-        delete columnsOrderExpanded;
-        columnsOrderExpanded = nullptr;
-        delete autoincFields;
-        autoincFields = nullptr;
-        autoIncrementSQLFieldsList.clear();
-        columnInfosByNameExpanded.clear();
-        columnInfosByName.clear();
-        delete ownedVisibleColumns;
-        ownedVisibleColumns = nullptr;
-        qDeleteAll(*fieldsExpanded);
-        delete fieldsExpanded;
-        fieldsExpanded = nullptr;
-        delete visibleFieldsExpanded; // NO qDeleteAll, items not owned
-        visibleFieldsExpanded = nullptr;
-        if (internalFields) {
-            qDeleteAll(*internalFields);
-            delete internalFields;
-            internalFields = nullptr;
-        }
-        delete fieldsExpandedWithInternalAndRecordId;
-        fieldsExpandedWithInternalAndRecordId = nullptr;
-        delete visibleFieldsExpandedWithInternalAndRecordId;
-        visibleFieldsExpandedWithInternalAndRecordId = nullptr;
-        delete fieldsExpandedWithInternal;
-        fieldsExpandedWithInternal = nullptr;
-        delete visibleFieldsExpandedWithInternal;
-        visibleFieldsExpandedWithInternal = nullptr;
+    if (recentConnection) {
+        recentConnection->d->removeFieldsExpanded(query);
     }
+    delete autoincFields;
+    autoincFields = nullptr;
+    autoIncrementSqlFieldsList.clear();
 }
 
-void KDbQuerySchema::Private::setColumnAlias(int position, const QString& alias)
+bool KDbQuerySchemaPrivate::setColumnAlias(int position, const QString& alias)
 {
     if (alias.isEmpty()) {
         columnAliases.remove(position);
         maxIndexWithAlias = -1;
-    } else {
-        setColumnAliasInternal(position, alias);
+        return true;
     }
+    return setColumnAliasInternal(position, alias);
 }
 
-void KDbQuerySchema::Private::tryRegenerateExprAliases()
+void KDbQuerySchemaPrivate::tryRegenerateExprAliases()
 {
     if (!regenerateExprAliases)
         return;
@@ -204,15 +135,25 @@ void KDbQuerySchema::Private::tryRegenerateExprAliases()
                 columnAlias = KDb::stringToIdentifier(columnAlias); // sanity fix, translators make mistakes!
             } while (-1 != tablePositionForAlias(columnAlias));
 
-            setColumnAliasInternal(p, columnAlias);
+            (void)setColumnAliasInternal(p, columnAlias);
         }
     }
     regenerateExprAliases = false;
 }
 
-void KDbQuerySchema::Private::setColumnAliasInternal(int position, const QString& alias)
+bool KDbQuerySchemaPrivate::setColumnAliasInternal(int position, const QString& alias)
 {
-    columnAliases.insert(position, alias.toLower());
-    columnPositionsForAliases.insert(alias.toLower(), position);
-    maxIndexWithAlias = qMax(maxIndexWithAlias, position);
+    const int currentPos = columnPositionsForAliases.value(alias.toLower(), -1);
+    if (currentPos == position) {
+        return true; // already set
+    }
+    if (currentPos == -1) {
+        columnAliases.insert(position, alias.toLower());
+        columnPositionsForAliases.insert(alias.toLower(), position);
+        maxIndexWithAlias = qMax(maxIndexWithAlias, position);
+        return true;
+    }
+    kdbWarning() << "Alias" << alias << "for already set for column" << currentPos
+                 << ", cannot set to a new column. Remove old alias first.";
+    return false;
 }
