@@ -95,10 +95,10 @@ bool SybaseConnection::drv_createDatabase(const QString &dbName)
 {
     //sybaseDebug() << dbName;
     // mysql_create_db deprecated, use SQL here.
-    if (drv_executeVoidSQL(KDbEscapedString("CREATE DATABASE ") + dbName)) {
+    if (drv_executeSql(KDbEscapedString("CREATE DATABASE ") + dbName)) {
         // set allow_nulls_by_default option to true
         KDbEscapedString allowNullsQuery = KDbEscapedString("sp_dboption %1, allow_nulls_by_default, true").arg(dbName);
-        if (drv_executeVoidSQL(allowNullsQuery.data()))
+        if (drv_executeSql(allowNullsQuery.data()))
             return true;
     }
     d->storeResult();
@@ -116,19 +116,19 @@ bool SybaseConnection::drv_useDatabase(const QString &dbName, bool *cancelled, K
 
 bool SybaseConnection::drv_closeDatabase()
 {
-// here we disconenct the connection
+// here we disconnect the connection
     return true;
 }
 
 bool SybaseConnection::drv_dropDatabase(const QString &dbName)
 {
 
-    return drv_executeVoidSQL(KDbEscapedString("DROP DATABASE ") + escapeString(dbName));
+    return drv_executeSql(KDbEscapedString("DROP DATABASE ") + escapeString(dbName));
 }
 
-bool SybaseConnection::drv_executeSQL(const KDbEscapedString& sql)
+bool SybaseConnection::drv_executeSql(const KDbEscapedString& sql)
 {
-    return d->executeSQL(sql);
+    return d->executeSql(sql);
 }
 
 quint64 SybaseConnection::drv_lastInsertRecordId()
@@ -179,7 +179,7 @@ bool KDbSybaseConnection::drv_beforeInsert(const QString& table, KDbFieldList* f
         return true;
 
     // explicit insertion into IDENTITY fields !!
-    return drv_executeVoidSQL(KDbEscapedString("SET IDENTITY_INSERT %1 ON").arg(escapeIdentifier(table)));
+    return drv_executeSql(KDbEscapedString("SET IDENTITY_INSERT %1 ON").arg(escapeIdentifier(table)));
 
 }
 
@@ -192,7 +192,7 @@ bool KDbSybaseConnection::drv_afterInsert(const QString& table, KDbFieldList* fi
         return true;
 
     // explicit insertion into IDENTITY fields has taken place. Turn off IDENTITY_INSERT
-    return drv_executeVoidSQL(KDbEscapedString("SET IDENTITY_INSERT %1 OFF").arg(escapeIdentifier(table)));
+    return drv_executeSql(KDbEscapedString("SET IDENTITY_INSERT %1 OFF").arg(escapeIdentifier(table)));
 
 }
 
@@ -202,7 +202,7 @@ bool KDbSybaseConnection::drv_beforeUpdate(const QString& table, KDbFieldList* f
         return true;
 
     // explicit update of IDENTITY fields has taken place.
-    return drv_executeVoidSQL(KDbEscapedString("SET IDENTITY_UPDATE %1 ON").arg(escapeIdentifier(table)));
+    return drv_executeSql(KDbEscapedString("SET IDENTITY_UPDATE %1 ON").arg(escapeIdentifier(table)));
 }
 
 bool KDbSybaseConnection::drv_afterUpdate(const QString& table, KDbFieldList& fields)
@@ -214,5 +214,5 @@ bool KDbSybaseConnection::drv_afterUpdate(const QString& table, KDbFieldList& fi
         return true;
 
     // explicit insertion into IDENTITY fields has taken place. Turn off IDENTITY_INSERT
-    return drv_executeVoidSQL(KDbEscapedString("SET IDENTITY_UPDATE %1 OFF").arg(escapeIdentifier(table)));
+    return drv_executeSql(KDbEscapedString("SET IDENTITY_UPDATE %1 OFF").arg(escapeIdentifier(table)));
 }
