@@ -34,11 +34,13 @@ class SybaseConnection : public KDbConnection
 public:
     virtual ~SybaseConnection();
 
-    KDbCursor* prepareQuery(const KDbEscapedString& sql, int cursor_options = 0) override Q_REQUIRED_RESULT;
-    KDbCursor* prepareQuery(KDbQuerySchema* query, int cursor_options = 0) override Q_REQUIRED_RESULT;
+    KDbCursor *prepareQuery(const KDbEscapedString &sql,
+                            int cursor_options = 0) override Q_REQUIRED_RESULT;
+    KDbCursor *prepareQuery(KDbQuerySchema *query,
+                            int cursor_options = 0) override Q_REQUIRED_RESULT;
 
     KDbPreparedStatement prepareStatement(KDbPreparedStatement::StatementType type,
-            KDbFieldList* fields) override;
+                                          KDbFieldList *fields) override;
 
 protected:
 
@@ -53,7 +55,7 @@ protected:
                                  KDbMessageHandler* msgHandler = 0);
     virtual bool drv_closeDatabase();
     virtual bool drv_dropDatabase(const QString &dbName = QString());
-    virtual bool drv_executeSQL(const KDbEscapedString& sql);
+    virtual bool drv_executeSql(const KDbEscapedString& sql);
     virtual quint64 drv_lastInsertRecordId();
 
     //! Implemented for KDbResultable
